%define		crates_ver	0.15.1

Summary:	A viewer for git and diff output
Name:		delta
Version:	0.15.1
Release:	1
License:	MIT
Group:		Applications
Source0:	https://github.com/dandavison/delta/archive/%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	6c219ab60d6a9dff5245c0f454f0b0aa
Source1:	%{name}-crates-%{crates_ver}.tar.xz
# Source1-md5:	cdf1ecb5b5f0e28b584e3d534e0692c9
URL:		https://github.com/dandavison/delta
BuildRequires:	cargo
BuildRequires:	libgit2-devel >= 1.4.0
BuildRequires:	oniguruma-devel >= 6.9.3
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 2.004
BuildRequires:	rust
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
Requires:	libgit2 >= 1.4.0
Requires:	oniguruma >= 6.9.3
ExclusiveArch:	%{rust_arches}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Delta aims to make studying diffs both efficient and enjoyable: it
allows you to make extensive changes to the layout and styling of
diffs, as well as allowing you to stay arbitrarily close to the
default git/diff output, changing just the aspects that you want to
change.

Delta's main features are:

- Language syntax highlighting with color themes
- Within-line highlights based on a Levenshtein edit inference
  algorithm
- Style (foreground color, background color, font attributes) can be
  configured independently for more than 20 different sections of the
  diff
- Stylable box/line decorations to draw attention to commit, file and
  hunk header sections.
- Line numbering (`-n`)
- `--diff-highlight` and `--diff-so-fancy` emulation modes
- Code can be copied directly from the diff (`-/+` markers are removed
  by default).
- `n` and `N` keybindings to move between files in large diffs, and
  between diffs in `log -p` views (`--navigate`) A viewer for git and
  diff output.

%prep
%setup -q -a1

%{__mv} delta-%{crates_ver}/* .
sed -i -e 's/@@VERSION@@/%{version}/' Cargo.lock

# use our offline registry
export CARGO_HOME="$(pwd)/.cargo"

mkdir -p "$CARGO_HOME"
cat >.cargo/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'

[source.vendored-sources]
directory = '$PWD/vendor'
EOF

%build
export CARGO_HOME="$(pwd)/.cargo"
export RUSTONIG_SYSTEM_LIBONIG=true

%cargo_build --frozen

%install
rm -rf $RPM_BUILD_ROOT
export CARGO_HOME="$(pwd)/.cargo"

%cargo_install --frozen --root $RPM_BUILD_ROOT%{_prefix} --path $PWD
%{__rm} $RPM_BUILD_ROOT%{_prefix}/.crates*

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README.md
%attr(755,root,root) %{_bindir}/delta
%changelog
* Tue Dec 06 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/delta.git;a=log;h=master

* Sat Dec 03 2022 Jan Palus <atler@pld-linux.org> bf53f80
- up to 0.15.1

* Thu Sep 01 2022 Jan Palus <atler@pld-linux.org> a1c7cc8
- up to 0.14.0

* Tue Jun 28 2022 Jan Palus <atler@pld-linux.org> 6e7b8bf
- bump required system libgit2 version; rel 2

* Sat May 14 2022 Jan Palus <atler@pld-linux.org> 8e00f91
- up to 0.13.0

* Sun Mar 06 2022 Jan Palus <atler@pld-linux.org> 7ac1dc6
- up to 0.12.1

* Sun Mar 06 2022 Jan Palus <atler@pld-linux.org> 8c4d23a
- drop create-crates.sh script in favor of rust-crates.sh

* Mon Feb 14 2022 Jan Palus <atler@pld-linux.org> a43129d
- up to 0.12.0

* Thu Dec 16 2021 Jan Palus <atler@pld-linux.org> 0f10bc3
- up to 0.11.3

* Wed Dec 08 2021 Jan Palus <atler@pld-linux.org> 60498c0
- up to 0.11.2

* Tue Dec 07 2021 Jan Palus <atler@pld-linux.org> 8f184b0
- up to 0.11.1

* Mon Dec 06 2021 Jan Palus <atler@pld-linux.org> 5e51bdb
- up to 0.11.0

* Sat Dec 04 2021 Jan Palus <atler@pld-linux.org> 6de4894
- up to 0.10.3

* Sun Nov 28 2021 Jan Palus <atler@pld-linux.org> 723627e
- up to 0.10.2

* Thu Nov 25 2021 Jan Palus <atler@pld-linux.org> 8a60a9a
- up to 0.10.1

* Thu Nov 25 2021 Jan Palus <atler@pld-linux.org> d9dd9ed
- up to 0.10.0

* Sat Oct 30 2021 Jan Palus <atler@pld-linux.org> 20f90e8
- up to 0.9.2

* Wed Oct 27 2021 Jan Palus <atler@pld-linux.org> 75089ef
- up to 0.9.1

* Sat Oct 23 2021 Jan Rękorajski <baggins@pld-linux.org> 1d3b2f5
- Release 3 (by relup.sh)

* Sun Sep 05 2021 Jan Rękorajski <baggins@pld-linux.org> 24dc4ee
- Release 2 (by relup.sh)

* Tue Jul 13 2021 Jan Palus <atler@pld-linux.org> 9e45a6d
- up to 0.8.3

